==> bitsensor-node-js-core-1.1.0.tgz: package/hook/sequelize.js <==
'use strict';
const stackTrace = require('stack-trace');
const Invocation = require('../index').Invocation;
const monkeypatch = require('monkeypatch');
const moment = require("moment");
const uuidv4 = require('uuid/v4');

// The purpose of this module is for tracing sql query executed by the client code.
module.exports = (exports, name) => {
  monkeypatch(exports.prototype, 'query', function (original) {
    let ret;
    bitSensor.apply(() => {
      bitSensor.traceIncrement()
      const args = [].slice.call(arguments, 1);

      // Prehandle
      let sqlInvocation = new Invocation.SQLInvocation();
      preHandle.call(this, sqlInvocation, args)

      sqlInvocation.queries.push({
        query: args[0]
      })
      let trace = stackTrace.get()[2];
      if (trace) {
        sqlInvocation.endpoint.location = trace.getFileName();
        sqlInvocation.endpoint.line = trace.getLineNumber().toString();
      }

      const invocationId = uuidv4();
      bitSensor.session.set(`sqlInvocation${invocationId}`, sqlInvocation);

      // Call original
      ret = original.apply(this, args)

      // Posthandle
      if (exports.version && exports.version.startsWith('4.')) {
        postHandle4.call(this, ret, invocationId);
      } else {
        postHandle1.call(this, ret, invocationId)
      }
    })

    return ret;
  });

  // Patch CLS
  if (exports.useCLS) {
    exports.useCLS(bitSensor.session);
  }
  else {
    monkeypatch(exports.Utils.CustomEventEmitter.prototype, 'done', function (original, fct) {
      bitSensor.session.bindEmitter(this);
      return original.call(this, fct);
    })
  }
  return exports;
}

function extend(base, sub, methods) {
  sub.prototype = Object.create(base.prototype);
  sub.prototype.constructor = sub;
  sub.base = base.prototype;

  // Copy the methods passed in to the prototype
  for (var name in methods) {
    sub.prototype[name] = methods[name];
  }
  // so we can define the constructor inline
  return sub;
}

function preHandle(sqlInvocation, args) {
  let endpoint = {
    url: `${this.options.dialect}://${this.options.host}:${this.options.port || ''}/${this.config.database}`,
    catalog: this.config.database,
    user: this.config.username,
    driver_version: `Sequelize ${this.Sequelize ? this.Sequelize.version : ''}`.trim(),
    database_type: this.getDialect(),
    start_time: moment().valueOf().toString(),
    successful: 'false'
  }

  Object.assign(sqlInvocation.endpoint, endpoint);
}

function postHandle4(ret, invocationId) {
  ret.bind(this).then(res => {
    let sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);
    let endpoint = {
      successful: 'true',
      execution_time: moment().diff(moment(sqlInvocation.endpoint.start_time, 'x')).toString(),
      database_version: this.options.databaseVersion
    }

    if (res[0] && res[0].dataValues) {
      Object.assign(endpoint, {
        result: 'true',
        hits: res.length.toString()
      });
    }

    Object.assign(sqlInvocation.endpoint, endpoint);

  }).finally(() => {
    let sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);

    bitSensor.apply(datapoint => {
      if (datapoint.invocation === null)
        datapoint.invocation = new Invocation();

      datapoint.invocation.sqlInvocations.push(sqlInvocation);
    });
  });
}

function postHandle1(ret, invocationId) {
  ret.done((err, res) => {
    let sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);
    let endpoint = {
      successful: 'true',
      execution_time: moment().diff(moment(sqlInvocation.endpoint.start_time, 'x')).toString(),
    }

    if (res && res[0] && res[0].dataValues) {
      Object.assign(endpoint, {
        result: 'true',
        hits: res.length.toString()
      });
    }

    Object.assign(sqlInvocation.endpoint, endpoint);

    bitSensor.apply(datapoint => {
      if (datapoint.invocation === null)
        datapoint.invocation = new Invocation();

      datapoint.invocation.sqlInvocations.push(sqlInvocation);
    });
    bitSensor.ship();
  });
}

==> bitsensor-node-js-core-2.0.1.tgz: package/hook/sequelize.js <==
const stackTrace = require('stack-trace');
const { Invocation } = require('../index');
const monkeypatch = require('monkeypatch');
const moment = require('moment');
const uuidv4 = require('uuid/v4');

// The purpose of this module is for tracing sql query executed by the client code.
module.exports = (exports, name) => {
  monkeypatch(exports.prototype, 'query', function (original) {
    let ret;
    bitSensor.apply(() => {
      bitSensor.traceIncrement();
      const args = [].slice.call(arguments, 1);

      // Prehandle
      const sqlInvocation = new Invocation.SQLInvocation();
      preHandle.call(this, sqlInvocation, args);

      sqlInvocation.queries.push({
        query: args[0],
      });
      const trace = stackTrace.get()[2];
      if (trace) {
        sqlInvocation.endpoint.location = trace.getFileName();
        sqlInvocation.endpoint.line = trace.getLineNumber().toString();
      }

      const invocationId = uuidv4();
      bitSensor.session.set(`sqlInvocation${invocationId}`, sqlInvocation);

      // Call original
      ret = original.apply(this, args)

      // Posthandle
      if (exports.version && exports.version.startsWith('4.')) {
        postHandle4.call(this, ret, invocationId);
      } else {
        postHandle1.call(this, ret, invocationId);
      }
    });

    return ret;
  });

  // Patch CLS
  if (exports.useCLS) {
    exports.useCLS(bitSensor.session);
  } else {
    monkeypatch(exports.Utils.CustomEventEmitter.prototype, 'done', function (original, fct) {
      bitSensor.session.bindEmitter(this);
      return original.call(this, fct);
    });
  }
  return exports;
};

function preHandle(sqlInvocation, args) {
  const endpoint = {
    url: `${this.options.dialect}://${this.options.host}:${this.options.port || ''}/${this.config.database}`,
    catalog: this.config.database,
    user: this.config.username,
    driver_version: `Sequelize ${this.Sequelize ? this.Sequelize.version : ''}`.trim(),
    database_type: this.getDialect(),
    start_time: moment().valueOf().toString(),
    successful: 'false',
  };

  Object.assign(sqlInvocation.endpoint, endpoint);
}

function postHandle4(ret, invocationId) {
  ret.bind(this).then((res) => {
    const sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);
    const endpoint = {
      successful: 'true',
      execution_time: moment().diff(moment(sqlInvocation.endpoint.start_time, 'x')).toString(),
      database_version: this.options.databaseVersion
    };

    if (res[0] && res[0].dataValues) {
      Object.assign(endpoint, {
        result: 'true',
        hits: res.length.toString(),
      });
    }

    Object.assign(sqlInvocation.endpoint, endpoint);
  }).finally(() => {
    const sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);

    bitSensor.apply((datapoint) => {
      if (datapoint.invocation === null) {
        datapoint.invocation = new Invocation();
      }

      datapoint.invocation.sqlInvocations.push(sqlInvocation);
    });
  });
}

function postHandle1(ret, invocationId) {
  ret.done((err, res) => {
    const sqlInvocation = bitSensor.session.get(`sqlInvocation${invocationId}`);
    const endpoint = {
      successful: 'true',
      execution_time: moment().diff(moment(sqlInvocation.endpoint.start_time, 'x')).toString(),
    };

    if (res && res[0] && res[0].dataValues) {
      Object.assign(endpoint, {
        result: 'true',
        hits: res.length.toString(),
      });
    }

    Object.assign(sqlInvocation.endpoint, endpoint);

    bitSensor.apply((datapoint) => {
      if (datapoint.invocation === null) {
        datapoint.invocation = new Invocation();
      }
      datapoint.invocation.sqlInvocations.push(sqlInvocation);
    });
    bitSensor.ship();
  });
}
